import React, { useState, useEffect } from "react";

import { BrowserRouter as Router, Switch, Route } from "react-router-dom";

import "../styles/App.css";
import Header from "./header";
import ListAnnonce from "./list-annonces";
import CreateAnnonce from "./createAnnonce";
import DetailAnnonce from "./detail-annonce";

import SignIn from "./../containers/SignIn";
import Register from "./../containers/Register";

import { AuthContext } from "./../contexts/AuthContext";

function App() {
  const [loggedIn, setLoggedIn] = useState(false);
  const [token, setToken] = useState(null);
  const [tokenExpirationTime, setTokenExpirationTime] = useState();

  const login = (token, expirationTime) => {
    setLoggedIn(true);
    setToken(token);

    const expiration =
      expirationTime || new Date(new Date().getTime() + 1000 * 60 * 60);

    setTokenExpirationTime(expiration);
    localStorage.setItem("token", token);
  };

  const logout = () => {
    setLoggedIn(false);
    setToken(null);

    localStorage.removeItem("token");
  };

  useEffect(() => {
    const storedData = JSON.parse(localStorage.getItem("userData"));
    if (
      storedData &&
      storedData.token &&
      new Date(storedData.expirationTime) > new Date()
    ) {
      login(storedData.token, new Date(storedData.expirationTime));
    }
  }, [login]);

  return (
    <AuthContext.Provider
      value={{ isLoggedIn: !!token, login: login, logout: logout }}
    >
      <Header />
      <Router>
        <div className="container">
          <Switch>
            <Route path="/annonces/create">
              <CreateAnnonce />
            </Route>

            <Route path="/sign-in">
              <SignIn />
            </Route>

            <Route path="/register">
              <Register />
            </Route>

            <Route path="/annonces/:annonceId">
              <DetailAnnonce />
            </Route>

            <Route path="/">
              <ListAnnonce />
            </Route>
          </Switch>
        </div>
      </Router>
    </AuthContext.Provider>
  );
}

export default App;
